import request from '@/utils/request'


// 查询导航列表
export function listNavigation(data) {
  return request({
    url: '/sist/navigation/list',
    method: 'post',
    data: data
  })
}

// 导出导航
export function exportNavigation(data) {
  return request({
    url: '/sist/navigation/export',
    method: 'post',
    data: data
  })
}

// 查询导航详细
export function getNavigation(id) {
  return request({
    url: '/sist/navigation/' + id,
    method: 'get'
  })
}

// 新增导航
export function addNavigation(data) {
  return request({
    url: '/sist/navigation',
    method: 'post',
    data: data
  })
}

// 修改导航
export function updateNavigation(data) {
  return request({
    url: '/sist/navigation',
    method: 'put',
    data: data
  })
}

// 修改导航
export function updateDetails(data) {
  return request({
    url: '/sist/article/details',
    method: 'put',
    data: data
  })
}
// 修改导航
export function getDetails(id) {
  return request({
    url: '/sist/article/getdetails/'+id,
    method: 'get',
  })
}

// 删除导航
export function delNavigation(id) {
  return request({
    url: '/sist/navigation/' + id,
    method: 'delete'
  })
}
